@@ -27,7 +27,13 @@ psi = function(date_time = "") {
   URL = parse_api_date(api = "environment/psi",
                        input_date = date_time,
                        summary = FALSE)
-  output = httr::GET(URL)
+
+  if (curl::has_internet()) {
+    output = httr::GET(URL)
+  } else {
+    message("No internet connection found.")
+    return(NULL)
+  }
 
   # Error check
   content.output = parse_api_output(output)
